@@ -33,9 +33,10 @@
 #  define CALENDAREVENTS_DEPRECATED_NO_EXPORT CALENDAREVENTS_NO_EXPORT CALENDAREVENTS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define CALENDAREVENTS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef CALENDAREVENTS_NO_DEPRECATED
+#    define CALENDAREVENTS_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* CALENDAREVENTS_EXPORT_H */
