@@ -86,7 +86,7 @@
 #define KDECLARATIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECLARATIVE_NO_DEPRECATED
-#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KDECLARATIVE_NO_DEPRECATED_WARNINGS
 #  define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -130,5 +130,12 @@
 #define KDECLARATIVE_DEPRECATED_VERSION_5(minor, text)      KDECLARATIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KDECLARATIVE_DEPRECATED_VERSION(major, minor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KDECLARATIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KDECLARATIVE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KDECLARATIVE_DEPRECATED_VERSION(major, minor, text)
+#  define KDECLARATIVE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDECLARATIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KDECLARATIVE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KDECLARATIVE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KDECLARATIVE_EXPORT_H */
